package org.edg.wl.dgas.dgassim.workload.rb;

import java.util.*;
import org.edg.wl.dgas.dgassim.*;
import org.edg.wl.dgas.dgassim.fabric.*;

/**
   implements a utility module used by the
   {@link org.edg.wl.dgas.dgassim.workload.rb.ResourceBroker ResourceBroker}
   for scheduling decisions. The <code><b>RandomUtilityModule</b></code> simply
   chooses a
   {@link org.edg.wl.dgas.dgassim.fabric.ComputingElement ComputingElement} at
   random.
 */
public class RandomUtilityModule implements UtilityModule {

    /**
       creates an instance.
     */
    public RandomUtilityModule() {
	// don't do anything
    }

    /**
       selects one of the
       {@link org.edg.wl.dgas.dgassim.fabric.ComputingElement ComputingElement}s
       for job submission (see the {@link RandomUtilityModule general class
       description}). The
       {@link org.edg.wl.dgas.dgassim.workload.rb.ResourceBroker ResourceBroker}
       will first use a
       {@link org.edg.wl.dgas.dgassim.workload.rb.Matchmaker Matchmaker} to get
       a set of matching resources for the given
       {@link org.edg.wl.dgas.dgassim.Job Job}.
       @return a reference to the selected
       {@link org.edg.wl.dgas.dgassim.fabric.ComputingElement ComputingElement}.
       @param ces an <code><b>ArrayList</b></code> of references to all matching
       {@link org.edg.wl.dgas.dgassim.fabric.ComputingElement ComputingElement}s
       as returned by the
       {@link org.edg.wl.dgas.dgassim.workload.rb.Matchmaker Matchmaker}.
       @param job the {@link org.edg.wl.dgas.dgassim.Job Job} for which to
       select a suitable resource.
     */
    public ComputingElement selectCE(ArrayList ces, Job job) {

	ArrayList selectedCEs = ces; // randomly choose one of ALL matching CEs

	if (selectedCEs.size() < 1) {
	    return null; // no CE found
	}

	// if we found at least one CE
	int ranIndex = (int) (((double)Math.random())*selectedCEs.size());
	return (ComputingElement) selectedCEs.get(ranIndex);
    }

}
